@@ -40,7 +40,6 @@
 
 #include <QtCore/QTextCodec>
 #include <QtCore/QBuffer>
-#include <QtCore/QRegExp>
 #include <QtCore/QByteArray>
 #include <QtCore/QLatin1Char>
 #include <kcodecs.h>
@@ -154,7 +153,7 @@ QByteArray KIMAP::decodeImapFolderName(const QByteArray &inSrc)
 
 QString KIMAP::decodeImapFolderName(const QString &inSrc)
 {
-    return QString::fromUtf8(decodeImapFolderName(inSrc.toUtf8()).data());
+    return QString::fromUtf8(decodeImapFolderName(inSrc.toUtf8()).constData());
 }
 
 //-----------------------------------------------------------------------------
@@ -192,7 +191,7 @@ QString KIMAP::quoteIMAP(const QString &src)
 //-----------------------------------------------------------------------------
 QString KIMAP::encodeImapFolderName(const QString &inSrc)
 {
-    return QString::fromUtf8(encodeImapFolderName(inSrc.toUtf8()).data());
+    return QString::fromUtf8(encodeImapFolderName(inSrc.toUtf8()).constData());
 }
 
 QByteArray KIMAP::encodeImapFolderName(const QByteArray &inSrc)
