@@ -19,13 +19,14 @@
 
 #include "setquotajob.h"
 
+#include <KLocalizedString>
 #include "kimap_debug.h"
 
 #include "quotajobbase_p.h"
 #include "message_p.h"
 #include "session_p.h"
 
-namespace KIMAP2
+namespace KIMAP
 {
 class SetQuotaJobPrivate : public QuotaJobBasePrivate
 {
@@ -38,10 +39,10 @@ public:
 };
 }
 
-using namespace KIMAP2;
+using namespace KIMAP;
 
 SetQuotaJob::SetQuotaJob(Session *session)
-    : QuotaJobBase(*new SetQuotaJobPrivate(session, "SetQuota"))
+    : QuotaJobBase(*new SetQuotaJobPrivate(session, i18n("SetQuota")))
 {
 }
 
@@ -63,9 +64,9 @@ void SetQuotaJob::doStart()
         s[s.length() - 1] = ')';
     }
 
-    qCDebug(KIMAP2_LOG) << "SETQUOTA " << '\"' + d->root + "\" " + s;
+    qCDebug(KIMAP_LOG) << "SETQUOTA " << '\"' + d->root + "\" " + s;
     //XXX: [alexmerry, 2010-07-24]: should d->root be quoted properly?
-    d->sendCommand("SETQUOTA", '\"' + d->root + "\" " + s);
+    d->tags << d->sessionInternal()->sendCommand("SETQUOTA", '\"' + d->root + "\" " + s);
 }
 
 void SetQuotaJob::handleResponse(const Message &response)
